@@ -27,8 +27,9 @@ import ipython_console_highlighting
 
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['mathmpl', 'math_symbol_table', 'sphinx.ext.autodoc',
-              'only_directives', 'plot_directive', 'inheritance_diagram',
+extensions = ['matplotlib.sphinxext.mathmpl', 'math_symbol_table',
+              'sphinx.ext.autodoc', 'matplotlib.sphinxext.only_directives',
+              'matplotlib.sphinxext.plot_directive', 'inheritance_diagram',
               'gen_gallery', 'gen_rst']
 
 # Add any paths that contain templates here, relative to this directory.
