@@ -92,7 +92,7 @@ Examples which work on this release:
  (3) - Clipping seems to be broken.
 """
 
-cvs_id = '$Id: backend_wx.py 7770 2009-09-16 23:38:54Z efiring $'
+cvs_id = '$Id: backend_wx.py 7924 2009-11-03 16:27:13Z mdboom $'
 
 
 import sys, os, os.path, math, StringIO, weakref, warnings
@@ -1794,7 +1794,7 @@ class NavigationToolbar2Wx(NavigationToolbar2, wx.ToolBar):
         default_file = "image." + self.canvas.get_default_filetype()
         dlg = wx.FileDialog(self._parent, "Save to file", "", default_file,
                             filetypes,
-                            wx.SAVE|wx.OVERWRITE_PROMPT|wx.CHANGE_DIR)
+                            wx.SAVE|wx.OVERWRITE_PROMPT)
         dlg.SetFilterIndex(filter_index)
         if dlg.ShowModal() == wx.ID_OK:
             dirname  = dlg.GetDirectory()
