@@ -13,9 +13,9 @@ Colorbar toolkit with two classes and a function:
         a function for resizing an axes and adding a second axes
         suitable for a colorbar
 
-The :meth:`matplotlib.Figure.colorbar` method uses :func:`make_axes`
-and :class:`Colorbar`; the :func:`matplotlib.pyplot.colorbar` function
-is a thin wrapper over :meth:`matplotlib.Figure.colorbar`.
+The :meth:`~matplotlib.figure.Figure.colorbar` method uses :func:`make_axes`
+and :class:`Colorbar`; the :func:`~matplotlib.pyplot.colorbar` function
+is a thin wrapper over :meth:`~matplotlib.figure.Figure.colorbar`.
 
 '''
 
@@ -29,18 +29,20 @@ import matplotlib.lines as lines
 import matplotlib.patches as patches
 import matplotlib.collections as collections
 import matplotlib.contour as contour
+import matplotlib.artist as martist
 
 make_axes_kw_doc = '''
 
-    ==========   ====================================================
-    Property     Description
-    ==========   ====================================================
-    *fraction*   0.15; fraction of original axes to use for colorbar
-    *pad*        0.05 if vertical, 0.15 if horizontal; fraction
-                 of original axes between colorbar and new image axes
-    *shrink*     1.0; fraction by which to shrink the colorbar
-    *aspect*     20; ratio of long to short dimensions
-    ==========   ====================================================
+    ============= ====================================================
+    Property      Description
+    ============= ====================================================
+    *orientation* vertical or horizontal
+    *fraction*    0.15; fraction of original axes to use for colorbar
+    *pad*         0.05 if vertical, 0.15 if horizontal; fraction
+                  of original axes between colorbar and new image axes
+    *shrink*      1.0; fraction by which to shrink the colorbar
+    *aspect*      20; ratio of long to short dimensions
+    ============= ====================================================
 
 '''
 
@@ -94,7 +96,7 @@ Add a colorbar to a plot.
 
 Function signatures for the :mod:`~matplotlib.pyplot` interface; all
 but the first are also method signatures for the
-:meth:`matplotlib.Figure.colorbar` method::
+:meth:`~matplotlib.figure.Figure.colorbar` method::
 
   colorbar(**kwargs)
   colorbar(mappable, **kwargs)
@@ -104,10 +106,11 @@ but the first are also method signatures for the
 arguments:
 
   *mappable*
-    the image, :class:`~matplotlib.contours.ContourSet`, etc. to
+    the :class:`~matplotlib.image.Image`,
+    :class:`~matplotlib.contour.ContourSet`, etc. to
     which the colorbar applies; this argument is mandatory for the
-    :meth:`matplotlib.Figure.colorbar` method but optional for the
-    :func:`matplotlib.pyplot.colorbar` function, which sets the
+    :meth:`~matplotlib.figure.Figure.colorbar` method but optional for the
+    :func:`~matplotlib.pyplot.colorbar` function, which sets the
     default to the current image.
 
 keyword arguments:
@@ -126,7 +129,7 @@ Additional keyword arguments are of two kinds:
   colorbar properties:
 %s
 
-If mappable is a :class:`~matplotlib.contours.ContourSet`, its *extend*
+If *mappable* is a :class:`~matplotlib.contours.ContourSet`, its *extend*
 kwarg is included automatically.
 
 Note that the *shrink* kwarg provides a simple way to keep a vertical
@@ -138,6 +141,13 @@ colorbar is too wide) use a smaller value of *shrink*.
 For more precise control, you can manually specify the positions of
 the axes objects in which the mappable and the colorbar are drawn.  In
 this case, do not use any of the axes properties kwargs.
+
+returns:
+    :class:`~matplotlib.colorbar.Colorbar` instance; see also its base class,
+    :class:`~matplotlib.colorbar.ColorbarBase`.  Call the
+    :meth:`~matplotlib.colorbar.ColorbarBase.set_label` method
+    to label the colorbar.
+
 ''' % (make_axes_kw_doc, colormap_kw_doc)
 
 
@@ -162,6 +172,19 @@ class ColorbarBase(cm.ScalarMappable):
 
         norm=colors.NoNorm.
 
+    Useful attributes:
+
+        :attr:`ax`
+            the Axes instance in which the colorbar is drawn
+
+        :attr:`lines`
+            a LineCollection if lines were drawn, otherwise None
+
+        :attr:`dividers`
+            a LineCollection if *drawedges* is True, otherwise None
+
+    Useful public methods are :meth:`set_label` and :meth:`add_lines`.
+
     '''
     _slice_dict = {'neither': slice(0,1000000),
                    'both': slice(1,-1),
@@ -196,6 +219,7 @@ class ColorbarBase(cm.ScalarMappable):
         self.filled = filled
         self.solids = None
         self.lines = None
+        self.dividers = None
         self.set_label('')
         if cbook.iterable(ticks):
             self.locator = ticker.FixedLocator(ticks, nbins=len(ticks))
@@ -272,6 +296,9 @@ class ColorbarBase(cm.ScalarMappable):
             self.ax.set_xlabel(self._label, **self._labelkw)
 
     def set_label(self, label, **kw):
+        '''
+        Label the long axis of the colorbar
+        '''
         self._label = label
         self._labelkw = kw
         self._set_label()
@@ -600,9 +627,10 @@ class Colorbar(ColorbarBase):
         self.mappable = mappable
         kw['cmap'] = mappable.cmap
         kw['norm'] = mappable.norm
-        kw['alpha'] = mappable.get_alpha()
+
         if isinstance(mappable, contour.ContourSet):
             CS = mappable
+            kw['alpha'] = mappable.get_alpha()
             kw['boundaries'] = CS._levels
             kw['values'] = CS.cvalues
             kw['extend'] = CS.extend
@@ -613,6 +641,9 @@ class Colorbar(ColorbarBase):
             if not CS.filled:
                 self.add_lines(CS)
         else:
+            if isinstance(mappable, martist.Artist):
+                kw['alpha'] = mappable.get_alpha()
+
             ColorbarBase.__init__(self, ax, **kw)
 
 
