@@ -3,8 +3,9 @@
 Matplotlib provides sophisticated date plotting capabilities, standing
 on the shoulders of python :mod:`datetime`, the add-on modules
 :mod:`pytz` and :mod:`dateutils`.  :class:`datetime` objects are
-converted to floating point numbers which represent the number of days
-since 0001-01-01 UTC.  The helper functions :func:`date2num`,
+converted to floating point numbers which represent time in days
+since 0001-01-01 UTC, plus 1.  For example, 0001-01-01, 06:00 is
+1.25, not 0.25.  The helper functions :func:`date2num`,
 :func:`num2date` and :func:`drange` are used to facilitate easy
 conversion to and from :mod:`datetime` and numeric ranges.
 
@@ -72,11 +73,18 @@ Here are all the date tickers:
       arbitrary date tick specifications.  See `rrule example
       <../examples/pylab_examples/date_demo_rrule.html>`_.
 
+    * :class:`AutoDateLocator`: On autoscale, this class picks the best
+      :class:`MultipleDateLocator` to set the view limits and the tick
+      locations.
+
 Date formatters
 ---------------
 
 Here all all the date formatters:
 
+    * :class:`AutoDateFormatter`: attempts to figure out the best format
+      to use.  This is most useful when used with the :class:`AutoDateLocator`.
+
     * :class:`DateFormatter`: use :func:`strftime` format strings
 
     * :class:`IndexDateFormatter`: date plots with implicit *x*
@@ -109,8 +117,9 @@ import dateutil.parser
 
 __all__ = ( 'date2num', 'num2date', 'drange', 'epoch2num',
             'num2epoch', 'mx2num', 'DateFormatter',
-            'IndexDateFormatter', 'DateLocator', 'RRuleLocator',
-            'YearLocator', 'MonthLocator', 'WeekdayLocator',
+            'IndexDateFormatter', 'AutoDateFormatter', 'DateLocator',
+            'RRuleLocator', 'AutoDateLocator', 'YearLocator',
+            'MonthLocator', 'WeekdayLocator',
             'DayLocator', 'HourLocator', 'MinuteLocator',
             'SecondLocator', 'rrule', 'MO', 'TU', 'WE', 'TH', 'FR',
             'SA', 'SU', 'YEARLY', 'MONTHLY', 'WEEKLY', 'DAILY',
@@ -217,7 +226,7 @@ def date2num(d):
     *d* is either a :class:`datetime` instance or a sequence of datetimes.
 
     Return value is a floating point number (or sequence of floats)
-    which gives number of days (fraction part represents hours,
+    which gives one plus the number of days (fraction part represents hours,
     minutes, seconds) since 0001-01-01 00:00:00 UTC.
     """
     if not cbook.iterable(d): return _to_ordinalf(d)
@@ -227,17 +236,18 @@ def date2num(d):
 def julian2num(j):
     'Convert a Julian date (or sequence) to a matplotlib date (or sequence).'
     if cbook.iterable(j): j = np.asarray(j)
-    return j + 1721425.5
+    return j - 1721424.5
 
 def num2julian(n):
     'Convert a matplotlib date (or sequence) to a Julian date (or sequence).'
     if cbook.iterable(n): n = np.asarray(n)
-    return n - 1721425.5
+    return n + 1721424.5
 
 def num2date(x, tz=None):
     """
-    *x* is a float value which gives number of days (fraction part
-    represents hours, minutes, seconds) since 0001-01-01 00:00:00 UTC.
+    *x* is a float value which gives one plus the number of days
+    (fraction part represents hours, minutes, seconds) since
+    0001-01-01 00:00:00 UTC.
 
     Return value is a :class:`datetime` instance in timezone *tz* (default to
     rcparams TZ value).
