@@ -580,6 +580,13 @@ in the normalized axes coordinate.
 
             handle = handle_list[-1]
             handlebox.add_artist(handle)
+
+            # special case for collection instances
+            if isinstance(handle, RegularPolyCollection) or \
+                   isinstance(handle, CircleCollection):
+                handle._transOffset = handlebox.get_transform()
+                handle.set_transform(None)
+
             if hasattr(handle, "_legmarker"):
                 handlebox.add_artist(handle._legmarker)
             handleboxes.append(handlebox)
