@@ -47,6 +47,10 @@ import subprocess
 
 basedir = {
     'win32'  : ['win32_static',],
+    'linux2-alpha' : ['/usr/local', '/usr'],
+    'linux2-hppa' : ['/usr/local', '/usr'],
+    'linux2-mips' : ['/usr/local', '/usr'],
+    'linux2-sparc' : ['/usr/local', '/usr'],
     'linux2' : ['/usr/local', '/usr'],
     'linux'  : ['/usr/local', '/usr',],
     'cygwin' : ['/usr/local', '/usr',],
@@ -65,6 +69,8 @@ basedir = {
     'sunos5' : [os.getenv('MPLIB_BASE') or '/usr/local',],
     'gnukfreebsd5' : ['/usr/local', '/usr'],
     'gnukfreebsd6' : ['/usr/local', '/usr'],
+    'gnukfreebsd7' : ['/usr/local', '/usr'],
+    'gnukfreebsd8' : ['/usr/local', '/usr'],
     'aix5' : ['/usr/local'],
 }
 
@@ -493,9 +499,10 @@ def check_for_numpy():
         return False
     nn = numpy.__version__.split('.')
     if not (int(nn[0]) >= 1 and int(nn[1]) >= 1):
-        print_message(
-           'numpy 1.1 or later is required; you have %s' % numpy.__version__)
-        return False
+        if not int(nn[0]) >= 1:
+            print_message(
+                'numpy 1.1 or later is required; you have %s' % numpy.__version__)
+            return False
     module = Extension('test', [])
     add_numpy_flags(module)
     add_base_flags(module)
@@ -850,7 +857,11 @@ def query_tcltk():
         else:
             tcl_lib_dir = str(tcl.getvar('tcl_library'))
             # Guess Tk location based on Tcl location
-            tk_lib_dir = tcl_lib_dir.replace('Tcl', 'Tk').replace('tcl', 'tk')
+            (head, tail) = os.path.split(tcl_lib_dir)
+            tail = tail.replace('Tcl', 'Tk').replace('tcl', 'tk')
+            tk_lib_dir = os.path.join(head, tail)
+            if not os.path.exists(tk_lib_dir):
+                tk_lib_dir = tcl_lib_dir.replace('Tcl', 'Tk').replace('tcl', 'tk')
     else:
         # Obtain Tcl and Tk locations from Tk widget
         tk.withdraw()
@@ -1095,7 +1106,7 @@ def build_ft2font(ext_modules, packages):
     deps.extend(glob.glob('CXX/*.c'))
 
     module = Extension('matplotlib.ft2font', deps,
-                       define_macros=[('PY_ARRAYAUNIQUE_SYMBOL', 'MPL_ARRAY_API')])
+                       define_macros=[('PY_ARRAY_UNIQUE_SYMBOL', 'MPL_ARRAY_API')])
     add_ft2font_flags(module)
     ext_modules.append(module)
     BUILT_FT2FONT = True
