@@ -568,11 +568,15 @@ public:
             }
             m_after_moveto = false;
 
+            /* NOTE: We used to skip this very short segments, but if
+               you have a lot of them cumulatively, you can miss
+               maxima or minima in the data. */
+
             /* Don't render line segments less than one pixel long */
-            if (fabs(*x - m_lastx) < 1.0 && fabs(*y - m_lasty) < 1.0)
-            {
-                continue;
-            }
+            /* if (fabs(*x - m_lastx) < 1.0 && fabs(*y - m_lasty) < 1.0) */
+            /* { */
+            /*     continue; */
+            /* } */
 
             /* if we have no orig vector, set it to this vector and
                continue.  this orig vector is the reference vector we
@@ -649,7 +653,7 @@ public:
                 }
                 else
                 {
-                    if (paradNorm2 > m_dnorm2Min)
+                    if (paradNorm2 < m_dnorm2Min)
                     {
                         m_dnorm2Min = paradNorm2;
                         m_nextX = *x;
@@ -680,9 +684,15 @@ public:
         {
             if (m_origdNorm2 != 0.0)
             {
-                queue_push(agg::path_cmd_line_to, m_nextX, m_nextY);
+              queue_push((m_moveto || m_after_moveto) ?
+                         agg::path_cmd_move_to : agg::path_cmd_line_to,
+                         m_nextX, m_nextY);
+              m_moveto = false;
             }
-            queue_push(agg::path_cmd_line_to, m_lastx, m_lasty);
+            queue_push((m_moveto || m_after_moveto) ?
+                       agg::path_cmd_move_to : agg::path_cmd_line_to,
+                       m_lastx, m_lasty);
+            m_moveto = false;
             queue_push(agg::path_cmd_stop, 0.0, 0.0);
         }
 
